/*  basic.h -- general macro definitions for all programs  */

#ifndef BASIC_H
#define BASIC_H

#include <limits.h>

/*
 * =========== Common Constants =============
 */
#ifndef PI
#define PI 3.1415926535897932385
#endif

#define ARCSEC_PER_RAD ((360 * 60 * 60) / (2.0 * PI))
#define METERS_PER_ARCSEC (1.0e7 / (90 * 60 * 60))
#define METERS_PER_FEET 0.3048

/*
 * =========== Common Macros =============
 */
#ifndef MAX
#define MAX(a, b) (((a)>(b))?(a):(b))
#endif

#ifndef MIN
#define MIN(a, b) (((a)>(b))?(b):(a))
#endif

#ifndef ABS
#define ABS(x) (((x)<0)?(-(x)):(x))
#endif

#ifndef ROUND
#define ROUND(a) ((int)((a)+0.5))
#endif

/*
 * ============ Common Structures ============
 */

typedef struct { double u, v; } UV;
typedef int Coord2d[2];

typedef struct {
    double ua, ub, uc, ud;
    double va, vb, vc, vd;
} Transform;

/*
 * ============ Common prototypes ============
 */

/* trans.c */
Transform *createTransform(UV swS, UV nwS, UV neS, UV seS,
			   UV swT, UV nwT, UV neT, UV seT);
void transform(Transform *f, UV s, UV *t);
void utm2ll(int zone, UV utm, UV *ll);

/* utils.c */
void nospace(void);
double getTime(void);



#endif   /* BASIC_H */
