/*  defns.h --  structures, types, and macros for TopoVista  */

#ifndef DEFNS_H
#define DEFNS_H
/*
 * ============= Testing =================
 */
#define TESTING 1

/*
 * ============= Display =================
 */
#define HEIGHT_3D  400		/* height of 3-D (perspective) window */
#define WIDTH_3D   600
#define HEIGHT_2D  256		/* height of 2-D (overhead) window */
				/* (width is calculated) */
#define EYE_HEIGHT 2.0		/* eye height above terrain (meters) */
#define REF_HEIGHT 0.0		/* reference height above terrain (meters) */

/* terrain display modes (these must be -2 and -1) */
#define T_CONTOURS -1	/* color-coded elevation contours */
#define T_GRAY -2	/* grayscale relief only */

#define SEA_LEVEL 1		/*  sea level: if -SEA_LEVEL <=
				    elevation <= SEA_LEVEL, color as
				    ocean  */

/* surface generation modes */
#define NONE2D	0	/* flag for no 2D mesh */
#define WIRE2D	1
#define FILL2D	2
#define WIRE3D	3
#define FILL3D	4

/* relief shading */
#define COLORATION 0.7		/* color importance (vs. shading) (0. to 1.) */
#define CONTRAST   4.0		/* contrast stretching factor for relief */


typedef struct {		/* rgb spec for elevation coloring */
    double red,green,blue;
} Color;



/*
 * ============== Heirarchy ===============
 */
#define MAXERR USHRT_MAX	/* maximum scaled triangle error */

/* triangle info flag bits */
#define SMALLER1	  1	/* Is neighbor 1 smaller? */
#define SMALLER2	  2	/* Is neighbor 2 smaller? */
#define BIGGER3		  4	/* Is neighbor 3 larger? */
#define SURFACE		  8	/* on surface? */
#define ALLINFOV	 16	/* completely in field of view? */
#define PARTINFOV	 32	/* partially in field of view? */
#define ALLINROD	 64	/* completely in rectangle of definition? */
#define PARTINROD	128	/* partially in rectangle of definition? */

/* info field access macros */
#define BORDER(hp,t) ((hp)->info[(t)->s] & PARTINROD)
#define INROD(hp,t) ((hp)->info[(t)->s] & ALLINROD)
#define PUTONSURFACE(hp,t) \
    (hp)->info[(t)->s] = ((hp)->info[(t)->s]&(ALLINROD|PARTINROD))|SURFACE
#define ONSURFACE(hp,t) ((hp)->info[(t)->s] & SURFACE)
#define INFOV(hp,t) ((hp)->info[(t)->s] & (ALLINFOV | PARTINFOV))
#define SMALLN1(hp,t) ((hp)->info[(t)->s] & SMALLER1)
#define SMALLN2(hp,t) ((hp)->info[(t)->s] & SMALLER2)
#define BIGN3(hp,t) ((hp)->info[(t)->s] & BIGGER3)

/* these macros also take TriIndex arguments */
#define ISLEAF(hp,t) ((t)->depth >= (hp)->depth)
#define IAMLEFTCHILD(t) ((((t)->depth&1)&&(((t)->orient^(t)->x)&1)) || \
			 ((((t)->depth&1)==0)&&(((t)->orient^(t)->x^(t)->y)&1)))
#define TRIEQUATE(a,b)  (a)->x=(b)->x; \
			(a)->y=(b)->y; \
			(a)->depth=(b)->depth; \
			(a)->orient=(b)->orient; \
			(a)->s=(b)->s


typedef struct {		/* triangle hierarchy */
    int depth;			/* maximum depth */
    int size;			/* number of triangles in hierarchy */
    int numSurfTri;		/* number of triangles on surface */
    unsigned short *err;	/* error of triangles */
    unsigned char *info;	/* surface,neighbor,infov of triangles */
} Hier;

typedef struct {	/* triangle index */
  int x,y;		/* coords of square containing tri at depth */
  int depth;		/* depth of triangle */
  int orient;		/* orientation */
  int s;		/* physical address */
} TriIndex;

/* initial values */
#define IERRTHRESH	0.001
#define IERRTHRESHINC	0.00005
#define IDISTTHRESH	700.0
#define IDISTTHRESHINC	50.0
#define IVEXAGGER	1.0
#define IVEXAGGERINC	0.1
#endif	/* DEFNS_H */
