/*  dem2pgm.c -- convert DEM file to PGM file  */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "dem.h"

int nogzip = 0;

void usage(char *progname)
{
  fprintf(stderr,
	  "usage: %s [-nogzip] [DEMfile [PGMfile]]\n", progname);
  fprintf(stderr,
	  "  -nogzip      don't try to gunzip input files.\n");
  exit(1);
}


int main(int argc, char *argv[])
{
  int i, j;
  FILE *out;
  int optind;
  char *inName,*outName;
  Dem *dem;
	
  optind = 1;
  if (argc > optind) {
    if (*(argv[optind])=='-') {
      if (!strcmp(argv[optind],"-nogzip")) {
	nogzip = 1;
	optind++;
      } else {
	usage(argv[0]);
      }
    }
  }
  if (argc > optind) {
    inName = argv[optind];
    optind++;
  } else {
    inName = NULL;
  }
  if (argc > optind) {
    outName = argv[optind];
    optind++;
  } else {
    outName = NULL;
  }
  if (argc > optind) usage(argv[0]);

  if (outName) {
    out = fopen(outName,"wb");
    if (out==NULL) {
      fprintf(stderr, "Can't open %s for write.\n",outName);
      exit(1);
    }
  } else {
    out = stdout;
  }

  dem = readDEM(inName);

  if (dem == NULL)
    exit(1);
	
  fprintf(stderr, "%s\n", dem->name);
  fprintf(stderr, "Writing...");
  fflush(stderr);
	
  fprintf(out, "P2\n");
  fprintf(out, "# produced by dem2pgm\n");
  fprintf(out, "%d %d\n", dem->cols, dem->rows);
  fprintf(out, "%d\n", (int)(dem->maxElevation));
  for (i = dem->rows - 1; i >= 0; --i) {
    for(j = 0; j < dem->cols; ++j) {
      fprintf(out, "%u ", dem->data[j][i]);
    }
    fprintf(out, "\n");
  }
  fprintf(stderr, "done\n");
	
  return 0;
}
