/*  globals.h -- global variables of TopoVista  */


/*
 *  variables prefaced by "global" are both declared and defined by this
 *  file, depending on how that macro is defined.
 */

#ifndef global
#define global extern
#define initial(v) /**/
#endif



/* windows (GL/GLUT handles) */

global int ctlWin;		/* control window */
global int ovhWin;		/* overhead ("2-D") window */
global int pspWin;		/* perspective ("3-D" window */


/* terrain data */

global Rgb **clayer;		/* array of color layers */
global char **layerName;	/* names of layers */
global int nLayers;		/* number of color layers */

global char *gemname;		/* name of elevation model */
global Em *gem;			/* global elevation model */

global int gemXmax, gemYmax;	/* maximum x, y indices in grid data */

global double xmeters, ymeters;	/* dimensions of data in meters */

global double xscale, yscale;	/* scales grid distance to meters */

global double m2grid;		/* scales vertical meters to grid units */

global double dz2contour;      	/* scales data to contour level */

global double high_water,low_water;/* SEA_LEVEL,-SEA_LEVEL in data units */

global double err2grid;		/* scales 0..MAXERR to grid units */

global Hier *hierarchy;		/* hierarchy pointer */

global TriIndex rootL, rootR;	/* initial Triangles */


/*  viewing options  */

global int colorLayer;		/* color layer to display */

global int twoDMesh	initial(NONE2D); /* show 2-D mesh? */
global int threeDMesh	initial(0);	/* show 3-D mesh? */

global int eyeUp	initial(1);	/* is eye above data plane? */

/* vertical exaggeration */
global double vexagger		initial(IVEXAGGER);
global double vexaggerInc	initial(IVEXAGGERINC);

global int cullBackface	initial(0);	/* cull backfaces */
global int cullFOV	initial(0);	/* cull outside of FOV */

/* parameters used to judge triangle fitness */
/* Triangle err/distance from eye must be < errThresh */
global double errThresh          initial(IERRTHRESH);
global double errThreshInc       initial(IERRTHRESHINC);

/* Triangles < k*distThresh meters from eye must have size < 2^k */
global double distThresh	initial(IDISTTHRESH);
global double distThreshInc	initial(IDISTTHRESHINC);


/* current viewpoint */

global double eyeEmx, eyeEmy, eyeEmz;	/* eye location */
global double refEmx, refEmy, refEmz;	/* reference point */
global double eye2refx, eye2refy, eye2refz;	/* eye to reference vector */



/* other */

global int numDisplayTri;		/* number of displayed triangles */

global double inAngleThresh;

global Coord2d se, sw, ne, nw;

global int tflag	initial(0);	/* calculate timing info? */
global int nogzip	initial(0);	/* skip gzip? */


#ifdef TESTING
global int doingLoop	initial(0);	/* doing a loop around perimeter? */
global int doRedraw	initial(1);	/* redraw every frame during loop? */
#endif


/* defined in main.c (too complex for macros above): */

extern Color elevMap[];		/* elevation colors */
extern int elevCount;		/* number of elevation colors */



/* these macros should not be used elsewhere */
#undef global
#undef initial
