/*  pnmops.h -- definitions for operating on PNM files  */


#ifndef PNMOPS_H
#define PNMOPS_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include "basic.h"
#include "config.h"

typedef struct {
  char *label;
  unsigned char red, green, blue;
} LegendEntry;

typedef struct {
  int size;
  LegendEntry *entry;
} Legend;


typedef struct {
  int width, height;
  Legend legend;
  UV swUV, nwUV, neUV, seUV;
  UV swXY, nwXY, neXY, seXY;
  unsigned char *red, *green, *blue;
  Transform *ll2xy;
} Pnm;


typedef struct {
  int width, height;
  Legend legend;
  unsigned char *red, *green, *blue;
} Rgb;

#define PNMRED(pnm, x, y) (*((pnm)->red + (pnm)->width*(int)(y) + (int)(x)))
#define PNMGREEN(pnm, x, y) (*((pnm)->green + (pnm)->width*(int)(y) + (int)(x)))
#define PNMBLUE(pnm, x, y) (*((pnm)->blue + (pnm)->width*(int)(y) + (int)(x)))

#define RED(rgb, x, y) (*((rgb)->red + (rgb)->width*(int)(y) + (int)(x)))
#define GREEN(rgb, x, y) (*((rgb)->green + (rgb)->width*(int)(y) + (int)(x)))
#define BLUE(rgb, x, y) (*((rgb)->blue + (rgb)->width*(int)(y) + (int)(x)))

#define REFPTHEADER	"#lon\t\tlat\t\tx\t\ty\n"
#define REFPTFORMATOUT	"# %f %f %f %f\n"
#define REFPTFORMATIN	"# %lf %lf %lf %lf\n"
#define TOPOFLAG	"#TopoVista1\n"
#define LEGENDFLAG	"#Legend\n"

/* ========== prototypes ================= */
/* pnmops.c */
Pnm *readPNM(char *filename);
Rgb *initRGB(int w, int h);
int findLegend(Legend l,unsigned char r,unsigned char g,unsigned char b);

#endif /* PNMOPS_H */
